@@ -1,5 +1,6 @@
 # coding=utf-8
 from . import *
+from .. import user_currency
 import os
 import json
 from urllib.parse import quote
@@ -10,13 +11,13 @@ v1_url = "https://v1.alapi.cn/api/"
 v2_url = "https://v2.alapi.cn/api/"
 
 
-def upload_image(filePath: str, plt_type: str = '', set_url: str = v1_url):
+def upload_image(file_path: str, plt_type: str = '', set_url: str = v1_url):
     """
     上传图片或Markdown中所有的图片到多平台（免API KEY，但不保证数据安全）
 
     Upload images or all images from Markdown to multiple platforms (API-free KEY, but data security is not guaranteed)
 
-    :param filePath: 图片或Markdown文件路径
+    :param file_path: 图片或Markdown文件路径
     :param plt_type: 平台（使用 qs -upload_image -help查看支持的平台）
     :param set_url: {v1_url} or {v2_url} 默认 v1
     :return: None
@@ -45,7 +46,11 @@ def upload_image(filePath: str, plt_type: str = '', set_url: str = v1_url):
             res_json = requests.post(set_url + 'image', files=file).text \
                 if not alapi_token else \
                 requests.post(set_url + 'image', files=file, headers={'token': alapi_token}).text
-        return json.loads(res_json)
+        try:
+            return json.loads(res_json)
+        except Exception as e:
+            qs_default_console.print(qs_error_string, repr(e), res_json)
+            return False
 
     def get_path(rt, rel):
         return os.path.abspath(rt + rel)
@@ -82,7 +87,7 @@ def upload_image(filePath: str, plt_type: str = '', set_url: str = v1_url):
                     try:
                         res_plt = list(res_dict['data']['url'].keys())[0]
                     except Exception:
-                        qs_default_console.print(qs_error_string, res_dict['code'], res_dict['msg'])
+                        qs_default_console.print(qs_error_string, res_dict)
                         res_table.add_row(aim.split(dir_char)[-1], str(res_dict['code']), res_dict['msg'])
                         img_dict[aim] = False
                     else:
@@ -104,26 +109,26 @@ def upload_image(filePath: str, plt_type: str = '', set_url: str = v1_url):
         qs_default_console.print(res_table, justify="center")
 
     try:
-        is_md = filePath.endswith('.md')
+        is_md = file_path.endswith('.md')
     except IndexError:
         qs_default_console.print(
             qs_error_string, 'Usage: qs -upimg {*.md} | {picture}'
             if user_lang != 'zh' else '使用: qs -upimg {Markdown文件} 或 {任意图片文件}')
     else:
         if is_md:
-            format_markdown(filePath)
+            format_markdown(file_path)
         else:
-            res = post_img(filePath)
+            res = post_img(file_path)
             if not res:
-                res_table.add_row(filePath.split(dir_char)[-1], 'No File', '')
+                res_table.add_row(file_path.split(dir_char)[-1], 'No File', '')
             else:
                 try:
                     plt_type = list(res['data']['url'].keys())[0]
                 except Exception:
-                    res_table.add_row(filePath.split(dir_char)[-1], str(res['code']), res['msg'])
+                    res_table.add_row(file_path.split(dir_char)[-1], str(res['code']), res['msg'])
                 else:
                     res_table.add_row(
-                        filePath.split(dir_char)[-1], str(res['code']), res['msg'] if res['code'] != 200 else (
+                        file_path.split(dir_char)[-1], str(res['code']), res['msg'] if res['code'] != 200 else (
                             res['data']['url'][plt_type] if res['data']['url'][plt_type]
                             else plt_type + ' failed'
                         )
@@ -143,20 +148,23 @@ def translate(text: str, from_lang: str = 'auto', to_lang: str = user_lang, set_
     :param set_url: {v1_url} or {v2_url} 默认 v1
     :return: 翻译的文本 | Translated text
     """
-    request_info = 'q={}&from={}&to={}'.format(quote(text, 'utf-8'), from_lang, to_lang) if from_lang \
-        else 'q={}&to={}'.format(quote(text, 'utf-8'), to_lang)
-    res = requests.post(set_url + 'fanyi', data=request_info,
-                        headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
-                        if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
-    if res.status_code == requests.codes.ok:
-        res = json.loads(res.text)
-        if res['code'] != 200:
-            return "[ERROR] {}".format(res['msg'])
-        return res['data']['trans_result'][0]['dst']
-    return "[ERROR] 未知错误 | Unknown Error"
+    try:
+        request_info = 'q={}&from={}&to={}'.format(quote(text, 'utf-8'), from_lang, to_lang) if from_lang \
+            else 'q={}&to={}'.format(quote(text, 'utf-8'), to_lang)
+        res = requests.post(set_url + 'fanyi', data=request_info,
+                            headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
+                            if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
+        if res.status_code == requests.codes.ok:
+            res = json.loads(res.text)
+            if res['code'] != 200:
+                return "[ERROR] {}".format(res['msg'])
+            return res['data']['trans_result'][0]['dst'] if set_url == v1_url else res['data']['dst']
+        return "[ERROR] 未知错误 | Unknown Error"
+    except Exception as e:
+        return f"[ERROR] {repr(e)}"
 
 
-def bili_cover(url: str, set_url: str = v1_url):
+def bili_cover(url: str, set_url: str = v2_url):
     """
     获取BiliBili视频封面
 
@@ -169,9 +177,12 @@ def bili_cover(url: str, set_url: str = v1_url):
     import re
     from ..NetTools.NormalDL import normal_dl
     from .. import qs_default_console, qs_error_string, qs_info_string
-    res = requests.post(set_url + 'bbcover', data='c=' + url,
-                        headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token}
-                        if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
+    try:
+        res = requests.post(set_url + ('bbcover' if set_url == v1_url else 'bilibili/cover'), data='c=' + url,
+                            headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token}
+                            if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
+    except Exception as e:
+        return qs_default_console.print(qs_error_string, repr(e))
     if res.status_code == requests.codes.ok:
         res = json.loads(res.text)
         if res['code'] != 200 or res['msg'] != 'success':
@@ -195,7 +206,7 @@ def bili_cover(url: str, set_url: str = v1_url):
                                f"Get cover with: {url} failed" if user_lang != 'zh' else f'下载封面: {url} 失败')
 
 
-def ip_info(ip: str, set_url: str = v1_url):
+def ip_info(ip: str, set_url: str = v2_url):
     """
     获取ip的运营商、地理位置等数据
 
@@ -205,21 +216,21 @@ def ip_info(ip: str, set_url: str = v1_url):
     :param set_url: {v1_url} or {v2_url} 默认 v1
     :return: data dict {ip, isp, pos | ERROR MESSAGE, location | ERROR code}
     """
-    res = requests.post(set_url + 'ip', data="ip=%s&format=json" % ip,
-                        headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
-                        if ip and alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'}
-                        if ip else headers.update({'token': alapi_token} if alapi_token else headers))
     try:
+        res = requests.post(set_url + 'ip', data="ip=%s&format=json" % ip,
+                            headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
+                            if ip and alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'}
+                            if ip else headers.update({'token': alapi_token} if alapi_token else headers))
         res = json.loads(res.text)
         if res['code'] != 200:
             return {'ip': ip, 'isp': '', 'pos': res['msg'], 'location': '{code, %s}' % res['code']}
         return res['data']
-    except:
+    except Exception as e:
         return {'ip': ip, 'isp': '', 'pos': 'Network Error'
-        if user_lang != 'zh' else '网络错误', 'location': '{code, %s}' % res.status_code}
+        if user_lang != 'zh' else '网络错误', 'location': '{code, %s}' % repr(e)}
 
 
-def garbage_classification(query_ls: list, set_url: str = v1_url):
+def garbage_classification(query_ls: list, set_url: str = v2_url):
     """
     查询中国垃圾分类
 
@@ -230,7 +241,7 @@ def garbage_classification(query_ls: list, set_url: str = v1_url):
     :return: 查询结果的字符串表格 | string table
     """
     from .. import qs_default_console, cut_string
-    width = qs_default_console.width // 4 - 6
+    width = qs_default_console.width // 5 * 2 - 1
 
     def fmt_string(string, pre_num):
         return '\n' * pre_num + ' '.join(cut_string(string, width))
@@ -242,14 +253,15 @@ def garbage_classification(query_ls: list, set_url: str = v1_url):
     table = Table(*[
         Column('名称', justify="center", style='bold cyan'), Column('分类', justify="center"),
         Column('解释', justify="center"), Column('提示', justify="center"),
-    ], row_styles=['none', 'dim'], show_edge=False, box=box.SIMPLE, title='[bold underline] 查询结果')
+    ], row_styles=['none', 'dim'], show_edge=False, box=box.SIMPLE, title='[bold underline] 查询结果\n')
     first_flag = True
     for query_el in query_ls:
         if first_flag:
             first_flag = False
         else:
             table.add_row(Text('-', style='none'), Text('-', style='none'), '-', '-')
-        res = requests.post(set_url + "lajifenlei", data="name={}".format(quote(query_el, 'utf-8')),
+        res = requests.post(set_url + ("lajifenlei" if set_url == v1_url else 'garbage'),
+                            data="name={}".format(quote(query_el, 'utf-8')),
                             headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
                             if alapi_token else {'Content-Type': 'application/x-www-form-urlencoded'})
         if res.status_code == requests.codes.ok:
@@ -269,7 +281,7 @@ def garbage_classification(query_ls: list, set_url: str = v1_url):
                         [
                             '[bold green]可回收', '[bold red]有害',
                             '[bold yellow]厨余(湿)', '[bold blue]其他(干)'
-                        ][res['type'] - 1], half_rows[1]
+                        ][int(res['type']) - 1], half_rows[1]
                     ),
                     Text(fmt_string(res['explain'], half_rows[2]), justify='full'),
                     Text(fmt_string(res['tip'], half_rows[3]), justify='full')
@@ -281,7 +293,7 @@ def garbage_classification(query_ls: list, set_url: str = v1_url):
     return table
 
 
-def short_video_info(url: str, set_url: str = v1_url):
+def short_video_info(url: str, set_url: str = v2_url):
     """
     解析多平台短视频，并返回视频信息与下载直链
 
@@ -291,10 +303,10 @@ def short_video_info(url: str, set_url: str = v1_url):
     :param set_url: {v1_url} or {v2_url} 默认 v1
     :return:
     """
-    res = requests.post(set_url + "video/url", data="url={}".format(quote(url, 'utf-8')),
-                        headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
-                        if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
     try:
+        res = requests.post(set_url + "video/url", data="url={}".format(quote(url, 'utf-8')),
+                            headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
+                            if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
         res = json.loads(res.text)
         if res['code'] != 200:
             return False, {'title': res['msg'], 'cover_url': 'None', 'video_url': 'None', 'source': str(res['code'])}
@@ -304,7 +316,7 @@ def short_video_info(url: str, set_url: str = v1_url):
                        'cover_url': 'None', 'video_url': 'None', 'source': 'Unknown'}
 
 
-def acg(set_url: str = v1_url):
+def acg(set_url: str = v2_url):
     """
     随机获取一张acg图片链接
 
@@ -313,19 +325,19 @@ def acg(set_url: str = v1_url):
     :param set_url: {v1_url} or {v2_url} 默认 v1
     :return: acg image link
     """
-    res = requests.post(set_url + 'acg', data='format=json',
-                        headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
-                        if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
     try:
+        res = requests.post(set_url + 'acg', data='format=json',
+                            headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
+                            if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
         res = json.loads(res.text)
         if res['code'] != 200:
             return False, res['msg'], 0, 0
         return True, res['data']['url'], res['data']['width'], res['data']['height']
-    except:
-        return False, ('Network Error' if user_lang != 'zh' else '网络错误'), 0, 0
+    except Exception as e:
+        return False, repr(e), 0, 0
 
 
-def bingImg(set_url: str = v1_url):
+def bingImg(set_url: str = v2_url):
     """
     随机获取一张bing图片链接
 
@@ -334,16 +346,16 @@ def bingImg(set_url: str = v1_url):
     :param set_url: {v1_url} or {v2_url} 默认 v1
     :return: image link
     """
-    res = requests.post(set_url + 'bing', data='format=json',
-                        headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
-                        if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
     try:
+        res = requests.post(set_url + 'bing', data='format=json',
+                            headers={'Content-Type': "application/x-www-form-urlencoded", 'token': alapi_token}
+                            if alapi_token else {'Content-Type': "application/x-www-form-urlencoded"})
         res = json.loads(res.text)
         if res['code'] != 200:
             return False, res['msg'], ''
         return True, res['data']['url'], res['data']['copyright']
-    except:
-        return False, ('Network Error' if user_lang != 'zh' else '网络错误'), ''
+    except Exception as e:
+        return False, repr(e), ''
 
 
 def kdCheck(kd_number: str, set_url: str = v1_url):
@@ -356,12 +368,59 @@ def kdCheck(kd_number: str, set_url: str = v1_url):
     :param set_url: {v1_url} or {v2_url} 默认 v1
     :return: bool, list
     """
-    res = requests.post(set_url + 'kd', data="number=%s" % kd_number,
-                        headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token})
     try:
+        res = requests.post(set_url + 'kd', data="number=%s" % kd_number,
+                            headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token})
         res = json.loads(res.text)
         if res['code'] != 200:
             return False, 0, res['msg']
-        return True, (int(res['data']['status']) if 'status' in res['data'] else int(res['data']['state'])), res['data']['info']
+        return True, (int(res['data']['status']) if 'status' in res['data'] else int(res['data']['state'])), \
+               res['data']['info']
     except Exception as e:
-        return False, 0, '[ERROR] ' + repr(e)
+        return False, 0, repr(e)
+
+
+def pinyin(zh_str: str, set_url: str = v2_url):
+    """
+    查询中文的拼音
+
+    Query Chinese pinyin
+
+    :param zh_str: Chinese | 中文
+    :param set_url: {v1_url} or {v2_url} 默认 v1
+    :return:
+    """
+    try:
+        res = requests.post(set_url + 'pinyin', data=f'word={quote(zh_str, "utf-8")}&tone=1&abbr=0',
+                            headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token})
+        res = json.loads(res.text)
+        if res['code'] != 200:
+            return False, res['msg']
+        return True, res['data']['pinyin']
+    except Exception as e:
+        return False, repr(e)
+
+
+def exchange(fr, number, to=user_currency, set_url: str = v2_url):
+    """
+    查询<number> <fr> 对应 多少 <to>
+
+    Query <number> <fr> corresponding <number?> <to>
+
+    :param to: 待查询的币种
+    :param number: 待查询的货币数量
+    :param fr: 目标币种
+    :param set_url: {v1_url} or {v2_url} 默认 v1
+    :return:
+    """
+
+    try:
+        res = requests.get(set_url + 'exchange',
+                           params={'money': number, 'from': fr, 'to': to},
+                           headers={'Content-Type': 'application/x-www-form-urlencoded', 'token': alapi_token})
+        res = json.loads(res.text)
+        if res['code'] != 200:
+            return False, res['msg']
+        return True, res['data']
+    except Exception as e:
+        return False, repr(e)
